@@ -13,6 +13,7 @@ package Mwalk::Args;
 
 # import external classes/modules
 use Getopt::Long;
+use FileHandle;
 use Sys::Hostname;
 use Socket;
 
@@ -24,32 +25,39 @@ use strict qw( vars refs subs );
 my $TIME_ADVANCE = 1000;  # 1 sec.
 
 # member structure
-my %members = ( generation   => 0,
-	        rtcpFile     => "",
-		rtcpHandle   => undef,
-		mtraceFile   => "",
-                mtraceHandle => undef,
-		utraceFile   => "",
-                utraceHandle => undef,
-		recvFile     => "",
-		statFile     => "stats",
-	        dir          => ".",
-		source       => "",
-		block        => 0,
-		blocksize    => 10,
-		timestamp    => time,
-	        timeout      => 240,
-	        rtcpOutput   => 0,
-	        mtraceOutput => 0,
-	        utraceOutput => 0,
-		genOutput    => 0,
-		append       => 0,
-		build        => 0,
-		strict       => 0,
-		interactive  => 0,
-		verbose      => 0,
-		start        => 0,
-		stop         => 0
+my %members = ( generation      => 0,
+		configFile      => "",
+	        rtcpFile        => "",
+		rtcpHandle      => undef,
+		mtraceFile      => "",
+                mtraceHandle    => undef,
+		utraceFile      => "",
+                utraceHandle    => undef,
+		recvFile        => "",
+		statFile        => "stats",
+	        dir             => ".",
+		source          => "",
+		block           => 0,
+		blocksize       => 10,
+		timestamp       => time,
+	        timeout         => 240,
+	        rtcpOutput      => 0,
+	        mtraceOutput    => 0,
+	        utraceOutput    => 0,
+		genOutput       => 0,
+		append          => 0,
+		build           => 0,
+		strict          => 0,
+		interactive     => 0,
+		verbose         => 0,
+		start           => 0,
+		stop            => 0,
+		ping            => "ping",
+		pingFlags       => "-n",
+		mtrace          => "mtrace",
+		mtraceFlags     => "-n",
+		traceroute      => "traceroute",
+		tracerouteFlags => "-n"
 	      );
 
 
@@ -169,6 +177,10 @@ sub parse {
   # check for unprocessed arguments
   main::printUsage() if @ARGV or ! $ok;
 
+  # load config file if available
+  $self->{configFile} = $optctl{config} if exists( $optctl{config} ) and $optctl{config};
+  $self->parseConfig() if $self->{configFile};
+
   # assign options to args hash
   $self->{interactive} = $optctl{interactive} if exists( $optctl{interactive} );
   $self->{verbose} = $optctl{verbose} if exists( $optctl{verbose} );
@@ -245,6 +257,7 @@ sub save {
   # print arguments
   print $fh "ARGS:\n";
   print $fh "flags:$flags\n" if $flags;
+  print $fh "config:$self->{configFile}\n" if $self->{configFile};
   print $fh "dir:$self->{dir}\n";
   my $or = ($self->{rtcpOutput} || $self->{genOutput}) ? "(output)" : "";
   print $fh "rtcp:$self->{rtcpFile} $or\n" if $self->{rtcpFile}; 
@@ -260,6 +273,35 @@ sub save {
 }
 
 
+#
+# load values from a config file if specified
+#
+# params
+#   self reference
+#
+sub parseConfig {
+
+  my ($self) = @_;
+  my ($cf, $line);
+
+  # open config file
+  $cf = new FileHandle( "< $self->{configFile}" ) or die "Couldn't open config file $self->{configFile}: $!\n";
+
+  # read in each line and store config values
+  while( $line = <$cf> ) {
+    # ignore comments and blank lines
+    next if $line =~ m/^\s*\#/o or $line =~ m/^\s*$/o;
+
+    # parse key=value pairs
+    my ($key, $value) = ("", "");
+    if( ($key,$value) = ($line =~ m/^\s*(.+?)\s*=\s*(.+?)\s*(?:\#.*)?$/o) ) {
+      # save key and value in hash
+      $self->{$key} = $value;
+    }
+  }
+  close $cf;
+}
+
 
 #
 # class destructor
