@@ -336,11 +336,11 @@ sub generateMTrace {
   $mtrace->start( $mtrace->stop( $self->{args}{timestamp} ) );
   if( $mtrace->gateway() ) {
     $mtrace->type( "gateway" );
-    $mtrace->command( "mtrace -ng " . $mtrace->gateway() . " " . $mtrace->source() . " " . $mtrace->receiver() );
+    $mtrace->command( "$self->{args}{mtrace} $self->{args}{mtraceFlags} -g " . $mtrace->gateway() . " " . $mtrace->source() . " " . $mtrace->receiver() );
   } else {
     $mtrace->type( "source" );
     $mtrace->flip( 1 );
-    $mtrace->command( "mtrace -ns " . $mtrace->receiver() . " " . $mtrace->source() );
+    $mtrace->command( "$self->{args}{mtrace} $self->{args}{mtraceFlags} " . $mtrace->receiver() . " " . $mtrace->source() );
   }
   
   # run the trace command and parse the output
@@ -366,7 +366,7 @@ sub generateUTrace {
   # set traceroute state
   $utrace->start( $utrace->stop( $self->{args}{timestamp} ) );
   $utrace->receiver( $receiver );
-  $utrace->command( "traceroute -n " . $utrace->receiver() );
+  $utrace->command( "$self->{args}{traceroute} $self->{args}{tracerouteFlags} " . $utrace->receiver() );
 
   # run the trace command and parse the output
   $self->generateTrace( $utrace );
@@ -456,8 +456,10 @@ sub printLog {
   # copy temp log into main log
   print $log (<$tmp>);
 
-  # print the stop time
+  # print the stop time - flush log
+  $log->autoflush( 1 );
   print $log "\n# TIMESTAMP FINISH = $self->{args}{timestamp}\n";
+  $log->autoflush( 0 );
 
   close $tmp;
 }
