@@ -7,7 +7,7 @@
 
   Content : A class representing a single mtrace.
             
-  $Id: MTrace.java,v 1.5 2001/08/22 17:48:19 robertc Exp $ 
+  $Id: MTrace.java,v 1.6 2001/10/19 18:58:25 robertc Exp $ 
 */
 
 package mwalk.core;
@@ -31,6 +31,8 @@ public class MTrace {
     public boolean parsed = false;
     /** Whether the trace was complete */
     public boolean complete = false;
+    /** Whether the trace type is gateway */
+    public boolean gateway = false;
     /** Timestamp of the trace */
     public long time = 0;
     /** List of hops in the trace */
@@ -91,6 +93,9 @@ public class MTrace {
 		    else if( ! Config.source.equals( value ) )
 			throw new ConfigException( "trace has wrong source" );
 
+		} else if( label.equals( "type" ) ) {
+		    // save whether mtrace is a gateway trace
+		    gateway = value.equals( "gateway" );
 		} else if( label.equals( "start" ) ) {
 		    // save the start time of the mtrace
 		    time = Long.parseLong( value );
