@@ -36,8 +36,15 @@ import mwalk.util.VisitException;
 public class DegreeCountVisitor extends PrintVisitor implements DownVisitor {
 
     /** Base of keys in configuration file */
+    private static final String CFG_BASE = "DegreeCountVisitor.";
+    /** Default filename */
     private static final String DEF_FILENAME = "tree-degree";
 
+    /** Type of identifying data to print for each entry */
+    protected String type = "data";
+    /** Whether to report degrees only within a specific type of node */
+    protected boolean intraType = false;
+
 
     /**
      * Default constructor.
@@ -69,6 +76,27 @@ public class DegreeCountVisitor extends PrintVisitor implements DownVisitor {
     }
 
 
+    /**
+     * Initialize the visitor state.
+     *
+     * @param <code>Tree</code> current tree instance
+     * @return <code>boolean</code> whether to walk again
+     */
+    public boolean init( Tree tree ) {
+
+	super.init( tree );
+
+	// get type from config
+	String t = cfgString( CFG_BASE + "type" );
+	if( t != null )
+	    type = t;
+	// get intraType flag from config
+	intraType = cfgBoolean( CFG_BASE + "intraType" );
+
+	return( true );
+    }
+
+
     /**
      * Print visitor's header info at start of file.
      *
@@ -79,7 +107,37 @@ public class DegreeCountVisitor extends PrintVisitor implements DownVisitor {
 	super.printHeader( tree );
 
 	ps.println( "#" );
-	ps.println( "# depth\tdownstream receivers\ttotal degree\tgateway degree\tnon-gateway degree" );
+	ps.println( "# id\tdepth\tdownstream receivers\ttotal degree\tleaf degree\tinterior degree" );
+    }
+
+    /**
+     * Print a single line of data for a node.
+     *
+     * @param <code>Tree</code> current tree instance
+     * @param <code>TreeNode</code> current tree node
+     * @param <code>DegreeCount</code> current degree count
+     */
+    protected void printData( Tree tree, TreeNode node, DegreeCount count ) {
+
+	// get identifying value to print for each entry
+	Object id = node.data.get( type );
+	if( id == null )
+	    id = node.getIP();
+
+	int depth = 0;
+	try {
+	    // figure out our current depth
+	    depth = ((Integer)node.data.get( "depth" )).intValue();
+	    
+	} catch( Exception e ) {}
+	
+	// print out data, depth and degree of node
+	String line = id.toString() + "\t" + depth + "\t" + count.toString();
+	// add interior links
+	line += "\t" + (count.links - count.leafs);
+		
+	Config.verbose( this, line );
+	printData( tree, node, line );
     }
 
 
@@ -94,10 +152,15 @@ public class DegreeCountVisitor extends PrintVisitor implements DownVisitor {
      */
     public Object visitDown( Tree tree, TreeNode node ) {
 
-	// mark node as seen and visited
-	markVisited( node );
-	// just return a simple degree count for a single receiver (active or not)
-	return( new DegreeCount( eval.isActive( (Receiver)node ) ) );
+	// visit only once
+	DegreeCount count = null;
+	if( ! markVisited( node ) ) {
+	    // return basic count as a receiver (active or not?)
+	    boolean active = eval.isActive( (Receiver)node );
+	    count = new DegreeCount( active, node.data.get( type ) );
+	}
+
+	return( count );
     }
 
     /**
@@ -112,39 +175,35 @@ public class DegreeCountVisitor extends PrintVisitor implements DownVisitor {
      */
     public Object visitDown( Tree tree, TreeNode node, Vector list ) throws VisitException {
 
-	DegreeCount kids = new DegreeCount();
+	// get this node's data to match
+	Object data = node.data.get( type );
+	DegreeCount cnt = new DegreeCount( data );
 	
-	// mark node as seen and visited
-	if( ! markVisited( node ) ) {
-	    // figure whether this node is used in the current active tree
-	    for( Enumeration enum = list.elements(); enum.hasMoreElements(); )
-		try {
-		    // get count from next child
-		    DegreeCount count = (DegreeCount)enum.nextElement();
-		    // add count to current total
-		    kids.add( count );
-		    		    
-		} catch( NoSuchElementException nse ) {
-		} catch( Exception e ) {
-		    throw new VisitException( "error evaluating child activity" );
-		}
+	// mark node as seen and visited - only once
+	if( markVisited( node ) )
+	    return( cnt );
 
-	    if( kids.receivers > 0 ) {
-		int depth = 0;
-		try {
-		    // figure out our current depth
-		    depth = ((Integer)node.data).intValue();
-		    
-		} catch( Exception e ) {}
+	// add children's degree counts to our own
+	for( Enumeration enum = list.elements(); enum.hasMoreElements(); )
+	    try {
+		// get count from next child
+		DegreeCount count = (DegreeCount)enum.nextElement();
+		// add only same types if requested
+		if( ! intraType || data == null || data.equals( count.data ) )
+		    // add count to current total
+		    cnt.add( count );
+		else
+		    // still track the number of downstream receivers
+		    cnt.addReceivers( count );
 		
-		// print out depth and degree of node
-		String line = depth + "\t" + kids.toString() + "\t" + (kids.links - kids.glinks);
-		
-		Config.verbose( this, line );
-		printData( tree, line );
+	    } catch( NoSuchElementException nse ) {
+	    } catch( Exception e ) {
+		throw new VisitException( "error evaluating child activity" );
 	    }
-	}
 	
-	return( kids );
+	// print out depth and degree of node
+	printData( tree, node, cnt );
+
+	return( cnt );
     }
 }
