@@ -7,7 +7,7 @@
 
   Content : A visitor that exports an ascii representation of the current tree.
              
-  $Id: ExportVisitor.java,v 1.2 2001/08/22 17:45:07 robertc Exp $
+  $Id: ExportVisitor.java,v 1.4 2001/10/19 19:09:18 robertc Exp $
 */
 
 package mwalk.visitor;
@@ -85,8 +85,8 @@ public class ExportVisitor extends PrintVisitor implements DownVisitor {
  	if( cfgBoolean( CFG_BASE + "showIP" ) )
 	    showIP = true;
 
-	// setup a random evaluator
-	evaluator( new mwalk.eval.RandomEvaluator() );
+	// setup an evaluator
+	evaluator( new mwalk.eval.PrimaryPathEvaluator() );
 
 	return( super.init( tree ) );
     }
@@ -156,10 +156,12 @@ public class ExportVisitor extends PrintVisitor implements DownVisitor {
 	/* mangle IP unless requested otherwise */
 	if( ! showIP ) {
 	    // check if node already has an ID
-	    Integer newID = (Integer)node.data;
-	    if( newID == null )
-		// create a new ID
-		node.data = newID = new Integer( ++nextID );
+	    Integer newID = (Integer)node.data.get( "id" );
+	    if( newID == null ) {
+		// create a new ID and store it in the node
+		newID = new Integer( ++nextID );
+		node.data.put( "id", newID );
+	    }
 	    id = newID.toString();
 	}
 
