@@ -69,9 +69,9 @@ public class MergeVisitor extends AbstractVisitor implements DownVisitor {
 	// mark node seen and vistited
 	markVisited( node );
 	// clear activity totals since we're a receiver
-	node.data = null;
+	node.data.remove( "activity" );
 
-	return( node.data );
+	return( null );
     }
 
     /**
@@ -102,8 +102,9 @@ public class MergeVisitor extends AbstractVisitor implements DownVisitor {
 		    }
 		    
 		    // bound the links activity by the merged activities at the end-point
-		    if( links[l].node.data != null )
-			links[l].activity.bound( (PeriodTable)links[l].node.data );
+		    PeriodTable table = (PeriodTable)links[l].node.data.get( "activity" );
+		    if( table != null )
+			links[l].activity.bound( table );
 		    // merge this links table to save space
 		    links[l].activity.merge();
 		    // save a reference to the table to report total activity to node's parents
@@ -115,10 +116,10 @@ public class MergeVisitor extends AbstractVisitor implements DownVisitor {
 	    } else
 		tables = new PeriodTable[0];
 	    
-	    // merge all link activity to report total activity to node's parents
-	    node.data = PeriodTable.merge( tables );
+	    // merge all link activity to report total activity to node's parents	    
+	    node.data.put( "activity", PeriodTable.merge( tables ) );
 	} 	    
 	
-	return( node.data );
+	return( node.data.get( "activity" ) );
     }
 }
