@@ -8,7 +8,7 @@
   Content : An abstract visitor used as a bas class for visitors 
             wanting to print results out to a log file.
              
-  $Id: PrintVisitor.java,v 1.4 2001/08/22 17:45:07 robertc Exp $
+  $Id: PrintVisitor.java,v 1.5 2001/10/19 19:12:47 robertc Exp $
 */
 
 package mwalk.visitor;
@@ -92,6 +92,19 @@ public abstract class PrintVisitor extends AbstractVisitor {
 	ps.println( "# " + visitor + " output data - " + (new Date()).toString() );
     }
 
+    /**
+     * Print a single line of data.
+     *
+     * @param <code>Tree</code> current tree instance
+     * @param <code>TreeNode</code> current tree node
+     * @param <code>String</code> line to print
+     */
+    public void printData( Tree tree, TreeNode node, String line ) {
+
+	// print a line of data
+	printData( tree, line );
+    }
+
     /**
      * Print a single line of data.
      *
