@@ -88,7 +88,7 @@ public class RandomVisitor extends GlobalVisitor {
 	if( receivers == 0 ) {
 	    receivers = cfgInt( CFG_BASE + "receivers" );
 	    if( receivers <= 0 )
-		receivers = 1;
+		receivers = tree.receivers();
 	}
 	if( ! increment )
 	    increment = cfgBoolean( CFG_BASE + "increment" );
