@@ -94,8 +94,8 @@ public class UpathMetricVisitor extends BasicMetricVisitor {
 		    // get the receiver matching the ip
 		    Receiver recv = tree.getReceiver( ip );
 		    if( recv != null ) {
-			// set the unicast path
-			recv.data = upath;
+			// set the unicast path length
+			recv.data.put( "upath", upath );
 			recvs++;
 		    }
 		}
@@ -127,7 +127,7 @@ public class UpathMetricVisitor extends BasicMetricVisitor {
 	MetricCount count = new MetricCount( eval.isActive( (Receiver)node, time ) );
 	try {
 	    if( count.receivers > 0 )
-		count.ucastLinks = ((Integer)node.data).intValue();
+		count.ucastLinks = ((Integer)node.data.get( "upath" )).intValue();
 
 	} catch( Exception e ) {
 	    // consider receiver inactive if no valid unicast path length could be obtained
